@@ -1,9 +1,12 @@
 import math
 
+from musictool.note import SpecificNote
+
 
 class Pitch:
-    def __init__(self, hz_tuning: float = 440):
+    def __init__(self, hz_tuning: float = 440, origin_note: SpecificNote = SpecificNote('A', 5)):
         self.hz_tuning = hz_tuning
+        self.origin_note = origin_note
 
     def i_to_hz(self, i: float) -> float:
         return self.hz_tuning * 2 ** (i / 12)
@@ -11,6 +14,10 @@ class Pitch:
     def hz_to_i(self, hz: float) -> float:
         return 12 * math.log2(hz / self.hz_tuning)
 
+    def note_to_hz(self, note: SpecificNote) -> float:
+        print(note.i - self.origin_note.i, note - self.origin_note)
+        return self.i_to_hz(note.i - self.origin_note.i)
+
     @staticmethod
     def hz_to_px(hz: float, hz_min: float, hz_max: float, px_max: float) -> float:
         """Convert Hz to pixel position (using logarithmic scale)"""
